@@ -4,8 +4,8 @@
 */
 #include "juliakeywords.h"
 
-#include <repository.h>
-#include <KF5/KSyntaxHighlighting/Definition>
+#include <KSyntaxHighlighting/Repository>
+#include <KSyntaxHighlighting/Definition>
 
 JuliaKeywords::JuliaKeywords()
 {
