@@ -7,8 +7,8 @@
 
 #include <QDebug>
 
-#include <repository.h>
-#include <KF5/KSyntaxHighlighting/Definition>
+#include <KSyntaxHighlighting/Repository>
+#include <KSyntaxHighlighting/Definition>
 
 MaximaKeywords* MaximaKeywords::instance()
 {
