@@ -479,6 +479,9 @@ void TestMaxima::testTextQuotes()
     QVERIFY(e2->result() != nullptr);
     QCOMPARE(e2->result()->type(), (int)Cantor::TextResult::Type );
     QCOMPARE(e2->result()->data().toString(), QLatin1String("this is a \"quoted string\""));
+
+    auto* e = evalExp(QLatin1String("kill(t1, t2)"));
+    QVERIFY(e != nullptr);
 }
 
 void TestMaxima::testVariableModel()
@@ -523,6 +526,9 @@ void TestMaxima::testVariableModel()
 
     QVariant value3 = model->index(3,1).data();
     QCOMPARE(value3.toString(),QLatin1String("this is a \"quoted string\""));
+
+    auto* e = evalExp(QLatin1String("kill(all)"));
+    QVERIFY(e != nullptr);
 }
 
 void TestMaxima::testLispMode01()
@@ -545,9 +551,8 @@ void TestMaxima::testLispMode01()
     auto* e4 = evalExp(QLatin1String("5+5"));
     QVERIFY(e4 != nullptr);
 
-    //TODO: doesn't work in the test, works in Cantor though...
-//     QVERIFY(e4->result() != nullptr);
-//     QCOMPARE(cleanOutput(e4->result()->data().toString()), QLatin1String("10"));
+    QVERIFY(e4->result() != nullptr);
+    QCOMPARE(cleanOutput(e4->result()->data().toString()), QLatin1String("10"));
 }
 
 void TestMaxima::testLoginLogout()
