@@ -19,6 +19,7 @@
  */
 
 #include "sagesettingswidget.h"
+#include <QTimer>
 
 SageSettingsWidget::SageSettingsWidget(QWidget* parent, const QString& id) : BackendSettingsWidget(parent, id)
 {
@@ -30,4 +31,23 @@ SageSettingsWidget::SageSettingsWidget(QWidget* parent, const QString& id) : Bac
 
     connect(tabWidget, &QTabWidget::currentChanged, this, &BackendSettingsWidget::tabChanged);
     connect(kcfg_Path, &KUrlRequester::textChanged, this, &BackendSettingsWidget::fileNameChanged);
+    connect(kcfg_integratePlots, &QCheckBox::clicked, this, &SageSettingsWidget::integratePlotsChanged);
+
+    kcfg_inlinePlotFormat->setItemIcon(0, QIcon::fromTheme(QLatin1String("application-pdf")));
+    kcfg_inlinePlotFormat->setItemIcon(1, QIcon::fromTheme(QLatin1String("image-png")));
+
+    // return to the event loop to show the settings
+    // and then call the slot to update the state of the widgets
+    QTimer::singleShot(0, this, [=]() {
+        integratePlotsChanged(kcfg_integratePlots->isChecked());
+    });
+}
+
+void SageSettingsWidget::integratePlotsChanged(bool state)
+{
+    lPlotWidth->setEnabled(state);
+    kcfg_plotWidth->setEnabled(state);
+    lPlotHeight->setEnabled(state);
+    kcfg_plotHeight->setEnabled(state);
+    kcfg_inlinePlotFormat->setEnabled(state);
 }
